@@ -13,13 +13,12 @@ import re
 SERVICE = os.getenv('SERVICE', 'python')
 PROJECT_ID = os.getenv('PROJECT_ID', 'santoid-dev')
 
-client = google.cloud.logging.Client()
+client = google.cloud.logging.Client(project=PROJECT_ID)
 logger = client.logger(SERVICE)
 
-_TRACE_CONTEXT_HEADER_NAME = "x-cloud-trace-context"
+_TRACE_CONTEXT_HEADER_NAME = "X-CLOUD-TRACE-CONTEXT"
 _TRACE_CONTEXT_HEADER_FORMAT = r"(?P<trace_id>[0-9a-f]{32})\/(?P<span_id>[\d]{1,20});o=(?P<trace_flags>\d+)"
 _TRACE_CONTEXT_HEADER_RE = re.compile(_TRACE_CONTEXT_HEADER_FORMAT)
-_FIELDS = {_TRACE_CONTEXT_HEADER_NAME}
 
 RESOURCE = Resource(
     type="cloud_run_revision",
@@ -109,9 +108,9 @@ ctx = _Context
 
 
 def set_request_id(request: Request, response: Response):
-    cloud_trace_context = request.get_header('X-CLOUD-TRACE-CONTEXT', None)
+    cloud_trace_context = request.get_header(_TRACE_CONTEXT_HEADER_NAME, None)
 
-    if not cloud_trace_context:
+    if not cloud_trace_context is None:
         ctx.trace_id = str(uuid4())
         ctx.span_id = str(random.randint(1000000000000000000, 9999999999999999999))
         ctx.trace_flags = 'o=1'
@@ -128,7 +127,7 @@ def set_request_id(request: Request, response: Response):
 
     ctx.endpoint_api_userinfo = request.get_header('X-ENDPOINT-API-USERINFO', None)
 
-    request.context.cloud_trace_context = cloud_trace_context
+    request.context.x_cloud_trace_context = cloud_trace_context
     request.context.trace_id = ctx.trace_id
     request.context.span_id = ctx.span_id
     request.context.trace = f"projects/{PROJECT_ID}/traces/{ctx.x_cloud_trace_context}"
@@ -157,8 +156,6 @@ class LogMiddleware(object):
             resource=RESOURCE,
         )
 
-        request.context.start_time = time.time()
-
 
 class logging():
     @staticmethod
